/***************************************************************************/
/***  Name         : receiveor.sql                                       ***/
/***                                                                     ***/
/***  Description  : Stored procedure to receive inventory.              ***/
/***                                                                     ***/
/***  Author       : First Choice Software, Inc                          ***/
/***                 4412 Spicewood Springs Road Suite 701               ***/
/***                 Austin, TX 78759                                    ***/
/***                                                                     ***/
/***  Usage        : First Choice Confidential                           ***/
/***                                                                     ***/
/***  Preconditions: None known                                          ***/
/***                                                                     ***/
/***  Postcondition: None known                                          ***/
/***                                                                     ***/
/***  Platforms    : This version supports Oracle version 7.3.1 or       ***/
/***                  later.                                             ***/
/***                                                                     ***/
/***                                                                     ***/
/***  Copyright (C) 1999 First Choice Software, Inc.                     ***/
/***  All Rights Reserved                                                ***/
/***                                                                     ***/
/***************************************************************************/

CREATE OR REPLACE PROCEDURE receive(dtl_num IN VARCHAR2,
                  from_loc IN VARCHAR2,
                  from_bin IN VARCHAR2,
                  from_good IN NUMBER,
		  to_loc IN VARCHAR2,
		  to_bin IN VARCHAR2,
		  to_good IN NUMBER,
                  quantity IN NUMBER,
                  serial_num IN VARCHAR2,
                  status IN VARCHAR2,
                  carrier IN VARCHAR2,
                  waybill IN VARCHAR2,
                  poss_damage IN NUMBER,
                  not_prop_pack IN NUMBER,
                  route_to_test IN NUMBER,
		  user_name IN VARCHAR2,
		  receive_date IN VARCHAR2,
		  auto_close IN NUMBER,
                  use_fifo IN NUMBER,
                  gen_tb IN NUMBER,
		  ret_val IN OUT NUMBER)
IS
  r_time DATE;                          /* Date/time of the receive.       */
  past_time DATE;                       /* Date/time in past for time bomb.*/
  demand_qty NUMBER;                    /* Overall demand quantity.        */
  receive_qty NUMBER;                   /* Received qty (so far).          */
  sn VARCHAR2(30);                      /* Serial number to use.           */
  left_to_rec NUMBER;                   /* How many are left to receive?   */
  site_name VARCHAR2(80);               /* Name of the site.               */
  cond_title VARCHAR2(80);              /* Title of the condition.         */
  new_status VARCHAR2(80);              /* Title of default status for new */
                                        /*  condition.                     */
  sn_track NUMBER;                      /* Serial number track.            */
  req_type VARCHAR2(40);                /* Request type (adv exch...).     */
  add_str VARCHAR2(255);                /* Additional information string.  */
                    
  user_objid NUMBER;                    /* Objid of user record.           */
  emp_objid NUMBER;                     /* Employee objid for bus rule.    */
  dtl_objid NUMBER;                     /* Part request detail objid.      */
  cond_objid NUMBER;                    /* Condition objid.                */
  mod_objid NUMBER;                     /* Part revision objid.            */
  part_objid NUMBER;                    /* Part number objid.              */
  hdr_objid NUMBER;                     /* Part request header object.     */
  site_objid NUMBER;                    /* Site from header.               */
  gbst_objid NUMBER;                    /* Activity string objid.          */
  new_stat_objid NUMBER;                /* Objid of default status for new */
                                        /*  condition.                     */
  ret_int NUMBER;                       /* Return integer from other call. */
  cost FLOAT;                           /* Cost (for purchase orders).     */
  cost_str VARCHAR2(20);                /* Cost as a string.               */          
  pri VARCHAR2(40);                     /* Priority of part request.       */
          
  base_objid NUMBER;                    /* Base objid for all sequences.   */
  f_loc_objid NUMBER;                   /* Objid of from inventory location*/
  f_bin_objid NUMBER;                   /* Objid of from inventory bin.    */
  t_loc_objid NUMBER;                   /* Objid of to inventory location  */
  t_bin_objid NUMBER;                   /* Objid of to inventory bin.      */
  carrier_objid NUMBER;                 /* Objid of the carrier site.      */
  trans_objid NUMBER;                   /* Objid of the part_trans object. */
  recv_objid NUMBER;                    /* Objid of the receive object.    */          
  act1_objid NUMBER;                    /* Objid of activity log entry.    */
  act2_objid NUMBER;                    /* Objid of activity log entry.    */
  tb1_objid NUMBER;                     /* Objid of time_bomb entry.       */
  tb2_objid NUMBER;                     /* Objid of time_bomb entry.       */
  q_objid NUMBER;                       /* Objid of dispatch queue.        */
  t_str VARCHAR2(100);                  /* Temporary string.               */
  user_name1 VARCHAR2(30);              /* User name string.               */
  from_loc1 VARCHAR2(20);               /* From location string.           */
  from_bin1 VARCHAR2(20);               /* From bin string.                */
  use_int_fifo NUMBER;                  /* Internal use fifo flag.         */
BEGIN
					/* Get current date/time.          */
					/*  Only if one isn't supplied.    */
                                        /* Do so for time in the past.     */
  BEGIN
    IF LTRIM(RTRIM(receive_date)) = '' OR LTRIM(RTRIM(receive_date)) IS NULL
    THEN
      r_time := SYSDATE;
    ELSE
      IF INSTR(receive_date, ' ') > 0
      THEN
         r_time := TO_DATE(receive_date, 'MM/DD/RR HH:MI:SS AM');
      ELSE
         r_time := TO_DATE(receive_date, 'MM/DD/RR');
      END IF;
    END IF;

    past_time := ADD_MONTHS(r_time, -1);
  END;
  
                                        /* If no quantity to receive, error*/
  IF quantity < 1
  THEN
     ret_val := -1;
     GOTO end_proc;
  END IF;

                                        /* Cannot receive to same loc.     */
  IF from_loc = to_loc AND from_bin = to_bin AND from_good = to_good
  THEN
     ret_val := -2;
     GOTO end_proc;
  END IF;

					/* If no user name specified, find */
					/*  one in the config item. If that*/
					/*  isn't found, use default.      */
  BEGIN
    IF user_name IS NULL
    THEN
      SELECT str_value INTO user_name1 FROM table_config_itm 
      WHERE name = 'Default Logistics User';
    ELSE
      user_name1 := user_name;
    END IF;
  EXCEPTION
    WHEN NO_DATA_FOUND
    THEN
      user_name1 := 'ClearLogistics';
  END;

                                        /* Get user/employee If the        */
                                        /*   user isn't found, then        */
                                        /*  error and leave.               */
  BEGIN
    SELECT objid INTO user_objid
      FROM table_user
      WHERE login_name = user_name1;
    EXCEPTION
    WHEN NO_DATA_FOUND
    THEN
      ret_val := -3;
      GOTO end_proc;
  END;
  SELECT objid INTO emp_objid FROM table_employee 
    WHERE employee2user = user_objid;

                                        /* Get part request (demand_dtl).  */
                                        /*  and other info from detail.    */
                                        /*  If not found, error and leave. */
                                        /* Get the header number.          */
                                        /* Get the site name.              */
  BEGIN
    SELECT objid, demand_dtl2condition, demand_dtl2part_info, demand_qty,
           received_qty, demand_dtl2demand_hdr, request_type, serial_no,
           x_order_price, priority, demand_dtl_curq2queue INTO
           dtl_objid, cond_objid, mod_objid, demand_qty, receive_qty, 
           hdr_objid, req_type, sn, cost, pri, q_objid
      FROM table_demand_dtl
      WHERE detail_number = dtl_num;
    EXCEPTION
    WHEN NO_DATA_FOUND
    THEN
       ret_val := -4;
       GOTO end_proc;
  END;
  SELECT open_reqst2site INTO site_objid
    FROM table_demand_hdr WHERE objid = hdr_objid;
  SELECT name INTO site_name FROM table_site WHERE objid = site_objid;
 
                                        /* If currently dispatched, error. */
  IF q_objid IS NOT NULL
  THEN
    ret_val := -24;
    GOTO end_proc;
  END IF;

                                        /* Overwrite the serial number with*/
                                        /*  theirs if requested.           */
  IF serial_num IS NOT NULL
  THEN
     sn := serial_num;
  END IF;

                                        /* If there are no more that need  */
                                        /* be received, then error/exit.   */
  left_to_rec := demand_qty - receive_qty;
  IF left_to_rec <= 0
  THEN
     ret_val := -5;
     GOTO end_proc;
  END IF;

                                        /* Get the condition's title.      */
                                        /* See if the user can make the    */
                                        /*  transition to the proper cond  */
                                        /*  condition.                     */
                                        /* If not, error and leave.        */
  SELECT title INTO cond_title FROM table_condition WHERE objid = cond_objid;
  check_cl_trans(cond_title, 'Received', req_type, user_name1, ret_int);
  IF ret_int < 0
  THEN
     ret_val := -6 + ret_int;
     GOTO end_proc;
  END IF;

                                        /* Get activity objid. If not      */
                                        /*  found, error and exit.         */
  BEGIN
    SELECT objid INTO gbst_objid FROM table_gbst_elm WHERE rank = 12200;
    EXCEPTION
    WHEN NO_DATA_FOUND
    THEN
      ret_val := -10;
      GOTO end_proc;
  END;

                                        /* Get default status for new      */
                                        /*  condition. If error, leave.    */
  get_list_item('Received', status, new_status, new_stat_objid);
  IF new_status IS NULL OR new_status = ''
  THEN
     ret_val := -11;
     GOTO end_proc;
  END IF;

                                        /* If the from location is not     */
                                        /*  specified...                   */
					/* Get expense GL from config item.*/
					/* If not found, use the default.  */
  BEGIN
    IF from_loc IS NULL OR from_loc = ''
    THEN
       SELECT str_value INTO from_loc1 FROM table_config_itm
         WHERE name = 'Receive Expense GL';
    ELSE
       from_loc1 := from_loc;
       from_bin1 := from_bin;
    END IF;
       EXCEPTION
         WHEN NO_DATA_FOUND
         THEN
           from_loc1 := 'EXPGL';
           from_bin1 := '';
  END;

                                        /* Make sure inv location is OK.   */
  BEGIN
    SELECT objid INTO f_loc_objid FROM table_inv_locatn
      WHERE location_name = from_loc1 AND active = 1 AND inv_class <> 1;
    EXCEPTION
    WHEN NO_DATA_FOUND
    THEN
      ret_val := -12;
      GOTO end_proc;
  END;

                                        /* If you have First Choice Software
                                           logisitics modules and use the
                                           optional "shippable bin" feature,
                                           you may wish to uncomment the 
                                           following filter so that you may
                                           pick only from "shippable" bins.
                                           In this case, make sure that the
                                           x_shippable flag in table_inv_bin
                                           is set to 1.                    */
                                        /* Make sure inv bin is OK.        */
  BEGIN
    IF from_bin1 IS NULL
    THEN
      SELECT objid INTO f_bin_objid FROM table_inv_bin
        WHERE bin_name IS NULL AND active = 1 AND inv_bin2inv_locatn = f_loc_objid;
    ELSE
      SELECT objid INTO f_bin_objid FROM table_inv_bin
        WHERE bin_name = from_bin1 AND active = 1 AND inv_bin2inv_locatn = f_loc_objid;    
    END IF;
    EXCEPTION
    WHEN NO_DATA_FOUND
    THEN
      ret_val := -13;
      GOTO end_proc;
  END;

                                        /* Now do the same for the to loc. */
                                        /* Make sure inv location is OK.   */
  BEGIN
    SELECT objid INTO t_loc_objid FROM table_inv_locatn
      WHERE location_name = to_loc AND active = 1 AND inv_class <> 1;
    EXCEPTION
    WHEN NO_DATA_FOUND
    THEN
      ret_val := -14;
      GOTO end_proc;
  END;

                                        /* Make sure inv bin is OK.        */
  BEGIN
    IF to_bin IS NULL
    THEN
      SELECT objid INTO t_bin_objid FROM table_inv_bin
        WHERE bin_name IS NULL AND active = 1 AND inv_bin2inv_locatn = t_loc_objid;
    ELSE
      SELECT objid INTO t_bin_objid FROM table_inv_bin
        WHERE bin_name = to_bin AND active = 1 AND inv_bin2inv_locatn = t_loc_objid;
    END IF;
    EXCEPTION
    WHEN NO_DATA_FOUND
    THEN
      ret_val := -15;
      GOTO end_proc;
  END;

                                        /* Make sure the carrier is valid. */
  BEGIN
    SELECT objid INTO carrier_objid FROM table_site WHERE site_id = carrier;
    EXCEPTION
    WHEN NO_DATA_FOUND
    THEN
      ret_val := -16;
      GOTO end_proc;
  END;

                                        /* Get the part number serialization*/
                                        /* If a serialized part and no SN,  */
                                        /*  or if not a serialized part and */
                                        /*  they do have a SN, error.       */
  SELECT part_info2part_num INTO part_objid FROM table_mod_level
    WHERE objid = mod_objid;
  SELECT sn_track INTO sn_track FROM table_part_num WHERE objid = part_objid;
  IF sn_track = 0
  THEN
     IF sn IS NOT NULL
     THEN
        ret_val := -17;
        GOTO end_proc;
     END IF;
  ELSE
     IF sn IS NULL
     THEN
        ret_val := -18;
        GOTO end_proc;
     END IF;
  END IF;

                                        /* Assume a blank cost string.     */
                                        /* If they are using FIFO costing. */
                                        /* If there's a cost in the PR DTL */
                                        /*  (used for purchase orders), use*/
                                        /*  it. Otherwise, just use regular*/
                                        /*  FIFO costing.                  */
  cost_str := '';
  IF use_fifo = 1
  THEN
     IF cost > 0
     THEN
        use_int_fifo := 2;
        cost_str := TO_CHAR(cost);
     ELSE
        use_int_fifo := use_fifo;
     END IF;
  ELSE
     use_int_fifo := use_fifo;
  END IF;

                                        /* Get base objid for database.    */
                                        /* Get objid for recv_object.      */
  SELECT site_id*(268435456) INTO base_objid FROM adp_db_header;
  SELECT seq_recv_parts.nextval INTO recv_objid FROM dual;
  recv_objid := recv_objid + base_objid;

                                        /* Move the part (transaction).    */
                                        /* If any errors, report them.     */
  trans_internal(dtl_objid, recv_objid, mod_objid, part_objid,
        f_bin_objid, f_loc_objid, from_good, t_bin_objid, t_loc_objid,
        to_good, quantity, sn, 2, user_objid, r_time, '', '',
        0, use_int_fifo, cost_str, trans_objid, ret_val);
  IF ret_val < 0
  THEN
     ret_val := ret_val - 200;
     GOTO end_proc;
  END IF;

                                        /* Get the necessary objids.       */
  SELECT seq_act_entry.nextval INTO act1_objid FROM dual;
  act1_objid := act1_objid + base_objid;
  SELECT seq_act_entry.nextval INTO act2_objid FROM dual;
  act2_objid := act2_objid + base_objid;
  SELECT seq_time_bomb.nextval INTO tb1_objid FROM dual;
  tb1_objid := tb1_objid + base_objid;
  SELECT seq_time_bomb.nextval INTO tb2_objid FROM dual;
  tb2_objid := tb2_objid + base_objid;

                                        /* Insert recv_parts record. Update*/
                                        /*  part request, condition. Add   */
                                        /*  the act_entry and tb (if needed*/
  BEGIN
    INSERT INTO table_recv_parts (objid, recv_notes, route_testing, route_problem,
                 receipt_type, recv_carrier, waybill, ship_damage, proper_package,
                 recv_parts2part_info)
      VALUES (recv_objid, '', route_to_test, 0, 0, carrier, waybill, 
              poss_damage, not_prop_pack, mod_objid);
  
    UPDATE table_demand_dtl SET receipt_date = r_time, 
            received_qty = received_qty + quantity, dmnd_dtl_sts2gbst_elm = new_stat_objid
      WHERE objid = dtl_objid;

    UPDATE table_condition SET title = 'Received', condition = 1048576
      WHERE objid = cond_objid;

    t_str := TO_CHAR(quantity);
    add_str := 'Received ' || t_str || ' units at location: ' || to_loc ||
                        ', Bin: ' || to_bin;
    INSERT INTO table_act_entry (objid, act_code, entry_time, addnl_info, 
                proxy, removed, act_entry2demand_dtl, act_entry2user, entry_name2gbst_elm)
           VALUES (act1_objid, 12200, r_time, add_str, '', 0, dtl_objid,
                user_objid, gbst_objid);
    INSERT INTO table_act_entry (objid, act_code, entry_time, addnl_info, 
                proxy, removed, act_entry2part_trans, act_entry2user, entry_name2gbst_elm)
           VALUES (act2_objid, 12200, r_time, add_str, '', 0, trans_objid,
                user_objid, gbst_objid);

    IF gen_tb = 1
    THEN
       INSERT INTO table_time_bomb (objid, title, escalate_time, end_time, 
         focus_lowid, focus_type, suppl_info, time_period, flags, left_repeat,
         report_title, property_set, users, cmit_creator2employee) VALUES
         (tb1_objid, '', past_time, r_time, dtl_objid, 49, '', act1_objid,
         2228226, 0, '', '', '', emp_objid);
       INSERT INTO table_time_bomb (objid, title, escalate_time, end_time, 
         focus_lowid, focus_type, suppl_info, time_period, flags, left_repeat,
         report_title, property_set, users, cmit_creator2employee) VALUES
         (tb2_objid, '', past_time, r_time, trans_objid, 244, '', act2_objid,
         2228226, 0, '', '', '', emp_objid);
    END IF;
    COMMIT;
  END;

                                        /* If they asked for auto-close,   */
                                        /*  try to do it.                  */
                                        /* If they didn't receive them all */
                                        /*  just continue.                 */
  IF auto_close = 1
  THEN
    IF left_to_rec > quantity
    THEN
       GOTO final_check;
    END IF;
    
                                        /* Get default status for new      */
                                        /*  condition. If error, leave.    */
    get_list_item('RQST Closed', '', new_status, new_stat_objid);
    IF new_status IS NULL OR new_status = ''
    THEN
       ret_val := -19;
       GOTO end_proc;
    END IF;

                                        /* Get activity objid. If not      */
                                        /*  found, error and exit.         */
    BEGIN
      SELECT objid INTO gbst_objid FROM table_gbst_elm WHERE rank = 11500;
      EXCEPTION
      WHEN NO_DATA_FOUND
      THEN
      ret_val := -20;
      GOTO end_proc;
    END;

                                        /* Check to see if we can make the */
                                        /*  transition. If not, error.     */
    check_cl_trans('Received', 'Closed', req_type, user_name1, ret_int);
    IF ret_int < 0
    THEN
       ret_val := -20 + ret_int;
       GOTO end_proc;
    END IF;

                                        /* Get the necessary objids.       */
    SELECT seq_act_entry.nextval INTO act1_objid FROM dual;
    act1_objid := act1_objid + base_objid;
    SELECT seq_time_bomb.nextval INTO tb1_objid FROM dual;
    tb1_objid := tb1_objid + base_objid;
    r_time := r_time + 1 / (24 * 60 * 60);

                                        /* Update condition, PR detail.    */
                                        /* Add act_entry and tb (if needed)*/
                                        /* If all closed, close the header.*/
    BEGIN    
      UPDATE table_condition SET title = 'Closed', condition = 4
        WHERE objid = cond_objid;
     
      UPDATE table_demand_dtl SET dmnd_dtl_sts2gbst_elm = new_stat_objid,
        demand_dtl_wip2wipbin = NULL
        WHERE objid = dtl_objid;
     
      add_str := 'Request: ' || dtl_num || ', Priority: ' || pri ||
                        ', Site Name: ' || site_name || ', Condition: Closed, Status: ' ||
                        new_status;
      INSERT INTO table_act_entry (objid, act_code, entry_time, addnl_info, 
        proxy, removed, act_entry2demand_dtl, act_entry2user, entry_name2gbst_elm)
        VALUES (act1_objid, 11500, r_time, add_str, '', 0, dtl_objid,
                user_objid, gbst_objid);
       
       IF gen_tb = 1
       THEN
         INSERT INTO table_time_bomb (objid, title, escalate_time, end_time, 
           focus_lowid, focus_type, suppl_info, time_period, flags, left_repeat,
           report_title, property_set, users, cmit_creator2employee) VALUES
           (tb1_objid, '', past_time, r_time, dtl_objid, 49, '', act1_objid,
           524290, 0, '', '', '', emp_objid);
       END IF;
       
       SELECT MIN(objid) INTO dtl_objid FROM table_demand_dtl 
         WHERE demand_dtl2demand_hdr = hdr_objid AND demand_dtl_wip2wipbin IS NOT NULL;
       IF dtl_objid IS NULL
       THEN
         UPDATE table_demand_hdr SET request_status = 'Closed' 
           WHERE objid = hdr_objid;
       END IF;
    COMMIT;
    END;
  END IF;

<<final_check>>
                                        /* If we want to receive too many. */
                                        /*  That's OK, just give a warning.*/
  IF left_to_rec < quantity
  THEN
     ret_val := 1;
     GOTO end_proc;
  END IF;

  ret_val := 0;
<<end_proc>> NULL;
END;
/
show errors;

/***************************************************************************/
/* Receive all Part Requests in a Batch                                    */
/*                                                                         */
/* Copyright (C) 1999. First Choice Software, Inc. All Rights Reserved     */
/***************************************************************************/

CREATE OR REPLACE PROCEDURE receive_batch(bat_num IN VARCHAR2,
                  from_loc IN VARCHAR2,
                  from_bin IN VARCHAR2,
                  from_good IN NUMBER,
		  to_loc IN VARCHAR2,
		  to_bin IN VARCHAR2,
		  to_good IN NUMBER,
                  quantity IN NUMBER,
                  serial_num IN VARCHAR2,
                  status IN VARCHAR2,
                  carrier IN VARCHAR2,
                  waybill IN VARCHAR2,
                  poss_damage IN NUMBER,
                  not_prop_pack IN NUMBER,
                  route_to_test IN NUMBER,
		  user_name IN VARCHAR2,
		  receive_date IN VARCHAR2,
		  auto_close IN NUMBER,
                  use_fifo IN NUMBER,
                  gen_tb IN NUMBER,
                  ret_str1 IN OUT VARCHAR2,
		  ret_val IN OUT NUMBER)
IS
  bat_objid NUMBER;                     /* Batch objid.                    */
  dtl_num VARCHAR2(20);                 /* Each detail's number.           */
  t_ret NUMBER;                         /* Return code for API call for PR */
  t_str VARCHAR2(10);                   /* String for conversion.          */

					/* Declare a cursor to find the dtl*/
					/*  records in the batch.          */
  CURSOR bat_cursor IS 
   SELECT detail_number
     FROM table_demand_dtl
     WHERE demand_dtl2batch = bat_objid
     ORDER BY detail_number;
BEGIN
                                        /* Get the batch objid. If not     */
                                        /*  found, error and exit.         */
  BEGIN
    SELECT objid INTO bat_objid FROM table_batch WHERE batch_num = bat_num;
    EXCEPTION
    WHEN NO_DATA_FOUND
    THEN
      ret_val := -1;
      GOTO end_proc;
  END;

                                        /* Assume no errors.               */
  ret_val := 0;
  
					/* Open the cursor and get rows    */
					/*  until there are no more.       */
					/* For each, change the status.    */
					/* If there's an error, add the    */
					/*  error to the string. Else add 0*/
  OPEN bat_cursor;
  LOOP
    FETCH bat_cursor INTO dtl_num;
    EXIT WHEN bat_cursor%NOTFOUND;

    receive(dtl_num, from_loc, from_bin, from_good, to_loc, to_bin, to_good,
            quantity, serial_num, status, carrier, waybill, poss_damage,
            not_prop_pack, route_to_test, user_name, receive_date, auto_close,
            use_fifo, gen_tb, t_ret);
    IF t_ret <> 0
    THEN
       ret_val := -2;
       t_str := TO_CHAR(t_ret);
       ret_str1 := ret_str1 || t_str;
    ELSE
       ret_str1 := ret_str1 || '0';
    END IF;
  END LOOP;
  CLOSE bat_cursor;

<<end_proc>> NULL;
END;
/
show errors;

/***************************************************************************/
/* Permission Granting Statements.                                         */
/*                                                                         */
/* Copyright (C) 1999. First Choice Software, Inc. All Rights Reserved     */
/***************************************************************************/

grant execute on receive to clarify_user;
begin
  dbms_sql.parse(dbms_sql.open_cursor, 'drop public synonym receive', dbms_sql.native);
  exception
  when others
    then null;
end;
/
create public synonym receive for receive;

grant execute on receive_batch to clarify_user;
begin
  dbms_sql.parse(dbms_sql.open_cursor, 'drop public synonym receive_batch', dbms_sql.native);
  exception
  when others
    then null;
end;
/
create public synonym receive_batch for receive_batch;

/***************************************************************************/
/* Test Driver.                                                            */
/*                                                                         */
/* Copyright (C) 1999. First Choice Software, Inc. All Rights Reserved     */
/***************************************************************************/

CREATE OR REPLACE PROCEDURE test_proc
IS
  ret_val NUMBER;
  num_picked NUMBER;
  ret_str1 VARCHAR2(255);
BEGIN
/*  receive('4-2', 'EXPGL', '', 1, 'Austin', 'Bin 1', 1, 1, '2222', '', 'INT1', 
          'Waybill', 1, 0, 1, '', '', 1, 0, 1, ret_val); */
  receive_batch('Batch 2', 'EXPGL', '', 1, 'Austin', 'Bin 1', 1, 2, '', '', 'INT1', 
          'Waybill', 1, 0, 1, '', '', 1, 0, 1, ret_str1, ret_val); 
  dbms_output.put_line(ret_val);
  IF ret_val = -2
  THEN
     dbms_output.put_line(ret_str1);
  END IF;
END test_proc;
/
show errors;

grant execute on test_proc to clarify_user;
begin
  dbms_sql.parse(dbms_sql.open_cursor, 'drop public synonym test_proc', dbms_sql.native);
  exception
  when others
    then null;
end;
/
create public synonym test_proc for test_proc;

commit;