/***************************************************************************/
/***  Name         : receive.sql                                         ***/
/***                                                                     ***/
/***  Description  : Stored procedure to receive inventory.              ***/
/***                                                                     ***/
/***  Author       : First Choice Software, Inc                          ***/
/***                 4412 Spicewood Springs Road Suite 701               ***/
/***                 Austin, TX 78759                                    ***/
/***                                                                     ***/
/***  Usage        : First Choice Confidential                           ***/
/***                                                                     ***/
/***  Preconditions: None known                                          ***/
/***                                                                     ***/
/***  Postcondition: None known                                          ***/
/***                                                                     ***/
/***  Platforms    : This version supports SQL Server version 6.0 or     ***/
/***                  later.                                             ***/
/***                                                                     ***/
/***                                                                     ***/
/***  Copyright (C) 1997 First Choice Software, Inc.                     ***/
/***  All Rights Reserved                                                ***/
/***                                                                     ***/
/***************************************************************************/

/***************************************************************************/
/***     Header declarations.                                            ***/
/***************************************************************************/

use merc
go

IF EXISTS (SELECT * FROM sysobjects WHERE name = 'receive')
   DROP PROCEDURE receive
go

IF EXISTS (SELECT * FROM sysobjects WHERE name = 'receive_batch')
   DROP PROCEDURE receive_batch
go

/***************************************************************************/
/***     Receive inventory from outside.                                 ***/
/***************************************************************************/

CREATE PROCEDURE receive
		 @dtl_num VARCHAR(20),
                 @from_loc VARCHAR(20),
                 @from_bin VARCHAR(20),
                 @from_good INT,
		 @to_loc VARCHAR(20),
		 @to_bin VARCHAR(20),
		 @to_good INT,
                 @quantity INT,
                 @serial_num VARCHAR(30),
                 @status VARCHAR(80),
                 @carrier VARCHAR(40),
                 @waybill VARCHAR(40),
                 @poss_damage INT,
                 @not_prop_pack INT,
                 @route_to_test INT,
		 @user_name VARCHAR(30),
		 @receive_date VARCHAR(30),
		 @auto_close INT,
                 @use_fifo INT,
                 @gen_tb INT,
		 @ret_val INT OUTPUT AS
BEGIN
  DECLARE @r_time DATETIME,             /* Date/time of the receive.       */
          @past_time DATETIME,          /* Date/time in past for time bomb.*/
          @demand_qty INT,              /* Overall demand quantity.        */
          @receive_qty INT,             /* Received qty (so far).          */
          @sn VARCHAR(30),              /* Serial number to use.           */
          @left_to_rec INT,             /* How many are left to receive?   */
          @site_name VARCHAR(80),       /* Name of the site.               */
          @cond_title VARCHAR(80),      /* Title of the condition.         */
          @new_status VARCHAR(80),      /* Title of default status for new */
                                        /*  condition.                     */
          @sn_track INT,                /* Serial number track.            */
          @req_type VARCHAR(40),        /* Request type (adv exch...).     */
          @add_str VARCHAR(255),        /* Additional information string.  */
                    
          @user_objid INT,              /* Objid of user record.           */
          @emp_objid INT,               /* Employee objid for bus rule.    */
          @dtl_objid INT,               /* Part request detail objid.      */
          @cond_objid INT,              /* Condition objid.                */
          @mod_objid INT,               /* Part revision objid.            */
          @part_objid INT,              /* Part number objid.              */
          @hdr_objid INT,               /* Part request header object.     */
          @site_objid INT,              /* Site from header.               */
          @gbst_objid INT,              /* Activity string objid.          */
          @new_stat_objid INT,          /* Objid of default status for new */
                                        /*  condition.                     */
          @ret_int INT,                 /* Return integer from other call. */
          @cost REAL,                   /* Cost (for purchase orders).     */
          @cost_str VARCHAR(20),        /* Cost as a string.               */          
          @pri VARCHAR(40),             /* Priority of part request.       */
          
          @base_objid INT,              /* Base objid for all sequences.   */
          @f_loc_objid INT,             /* Objid of from inventory location*/
          @f_bin_objid INT,             /* Objid of from inventory bin.    */
          @t_loc_objid INT,             /* Objid of to inventory location  */
          @t_bin_objid INT,             /* Objid of to inventory bin.      */
          @carrier_objid INT,           /* Objid of the carrier site.      */
          @trans_objid INT,             /* Objid of the part_trans object. */
          @recv_objid INT,              /* Objid of the receive object.    */          
          @act1_objid INT,              /* Objid of activity log entry.    */
          @act2_objid INT,              /* Objid of activity log entry.    */
          @tb1_objid INT,               /* Objid of time_bomb entry.       */
          @tb2_objid INT,               /* Objid of time_bomb entry.       */
          @q_objid INT,                 /* Objid of dispatch queue.        */

@t_str VARCHAR(100)



                                        /* Get current date/time.          */
                                        /*  Only if one isn't supplied.    */
                                        /* Set time in past for timebomb.  */
  IF LTRIM(RTRIM(@receive_date)) = '' OR LTRIM(RTRIM(@receive_date)) IS NULL
  BEGIN
     SELECT @r_time = getdate()
  END
  ELSE
  BEGIN
     SELECT @r_time = CONVERT(datetime, @receive_date)
  END
  SELECT @past_time = DATEADD(mm, -1, @r_time)

                                        /* If no quantity to receive, error*/
  IF @quantity < 1
  BEGIN
     SELECT @ret_val = -1
     GOTO end_proc
  END

                                        /* Cannot receive to same loc.     */
  IF @from_loc = @to_loc AND @from_bin = @to_bin AND @from_good = @to_good
  BEGIN
     SELECT @ret_val = -2
     GOTO end_proc
  END

                                        /* If no user name specified, find */
                                        /*  one in the config item. If that*/
                                        /*  isn't found, use default.      */
  IF @user_name = ''
  BEGIN
     SELECT @user_name = str_value FROM table_config_itm 
       WHERE name = 'Default Logistics User'
     IF @user_name IS NULL OR @user_name = ''
     BEGIN
        SELECT @user_name = 'ClearLogistics'
     END
  END

                                        /* Get user/employee If the        */
                                        /*   user isn't found, then        */
                                        /*  error and leave.               */
  SELECT @user_objid = objid
    FROM table_user
    WHERE login_name = @user_name
  IF @user_objid IS NULL
  BEGIN
     SELECT @ret_val = -3
     GOTO end_proc
  END
  SELECT @emp_objid = objid FROM table_employee 
    WHERE employee2user = @user_objid

                                        /* Get part request (demand_dtl).  */
                                        /*  and other info from detail.    */
                                        /*  If not found, error and leave. */
                                        /* Get the header number.          */
                                        /* Get the site name.              */
  SELECT @dtl_objid = objid, @cond_objid = demand_dtl2condition,
         @mod_objid = demand_dtl2part_info, @demand_qty = demand_qty,
         @receive_qty = received_qty, @hdr_objid = demand_dtl2demand_hdr, 
         @req_type = request_type, @sn = serial_no, @cost = x_order_price,
         @pri = priority, @q_objid = demand_dtl_curq2queue
    FROM table_demand_dtl
    WHERE detail_number = @dtl_num
  IF @dtl_objid IS NULL
  BEGIN
    SELECT @ret_val = -4
    GOTO end_proc
  END
  SELECT @site_objid = open_reqst2site
    FROM table_demand_hdr WHERE objid = @hdr_objid
  SELECT @site_name = name FROM table_site WHERE objid = @site_objid
  
                                        /* If currently dispatched, error. */
  IF @q_objid IS NOT NULL
  BEGIN
    SELECT @ret_val = -24
    GOTO end_proc
  END

                                        /* Overwrite the serial number with*/
                                        /*  theirs if requested.           */
  IF @serial_num <> ''
  BEGIN
     SELECT @sn = @serial_num
  END

                                        /* If there are no more that need  */
                                        /* be received, then error/exit.   */
  SELECT @left_to_rec = @demand_qty - @receive_qty
  IF @left_to_rec <= 0
  BEGIN
     SELECT @ret_val = -5
     GOTO end_proc
  END

                                        /* Cannot receive multiple units   */
                                        /*  and specify a serial number.   */
  IF @quantity > 1 AND @sn <> ''
  BEGIN
     SELECT @ret_val = -6
     GOTO end_proc
  END

                                        /* Get the condition's title.      */
                                        /* See if the user can make the    */
                                        /*  transition to the proper cond  */
                                        /*  condition.                     */
                                        /* If not, error and leave.        */
  SELECT @cond_title = title FROM table_condition WHERE objid = @cond_objid
  EXEC check_cl_trans @cond_title, 'Received', @req_type, @user_name, 
                      @ret_int OUT
  IF @ret_int < 0
  BEGIN
     SELECT @ret_val = -6 + @ret_int
     GOTO end_proc
  END

                                        /* Get activity objid. If not      */
                                        /*  found, error and exit.         */
  SELECT @gbst_objid = objid FROM table_gbst_elm WHERE rank = 12200
  IF @gbst_objid IS NULL
  BEGIN
    SELECT @ret_val = -10
    GOTO end_proc
  END

                                        /* Get default status for new      */
                                        /*  condition. If error, leave.    */
  EXEC get_list_item 'Received', @status, @new_status OUT, @new_stat_objid OUT
  IF @new_status IS NULL OR @new_status = ''
  BEGIN
     SELECT @ret_val = -11
     GOTO end_proc
  END

                                        /* If the from location is not     */
                                        /*  specified...                   */
					/* Get expense GL from config item.*/
					/* If not found, use the default.  */
  IF @from_loc IS NULL OR @from_loc = ''
  BEGIN
     SELECT @from_loc = str_value FROM table_config_itm
       WHERE name = 'Receive Expense GL'
     IF @from_loc IS NULL OR @from_loc = ''
     BEGIN
        SELECT @from_loc = 'EXPGL'
     END
     SELECT @from_bin = ''
  END

                                        /* Make sure inv location is OK.   */
  SELECT @f_loc_objid = objid FROM table_inv_locatn
    WHERE location_name = @from_loc AND active = 1 AND inv_class <> 1
  IF @f_loc_objid IS NULL
  BEGIN
     SELECT @ret_val = -12
     GOTO end_proc
  END

                                        /* If you have First Choice Software
                                           logisitics modules and use the
                                           optional "shippable bin" feature,
                                           you may wish to uncomment the 
                                           following filter so that you may
                                           pick only from "shippable" bins.
                                           In this case, make sure that the
                                           x_shippable flag in table_inv_bin
                                           is set to 1.                    */
                                        /* Make sure inv bin is OK.        */
  SELECT @f_bin_objid = objid FROM table_inv_bin
    WHERE bin_name = @from_bin AND active = 1 AND inv_bin2inv_locatn = @f_loc_objid
  IF @f_bin_objid IS NULL
  BEGIN
     SELECT @ret_val = -13
     GOTO end_proc
  END

                                        /* Now do the same for the to loc. */
                                        /* Make sure inv location is OK.   */
  SELECT @t_loc_objid = objid FROM table_inv_locatn
    WHERE location_name = @to_loc AND active = 1 AND inv_class <> 1
  IF @t_loc_objid IS NULL
  BEGIN
     SELECT @ret_val = -14
     GOTO end_proc
  END

                                        /* Make sure inv bin is OK.        */
  SELECT @t_bin_objid = objid FROM table_inv_bin
    WHERE bin_name = @to_bin AND active = 1 AND inv_bin2inv_locatn = @t_loc_objid
  IF @t_bin_objid IS NULL
  BEGIN
     SELECT @ret_val = -15
     GOTO end_proc
  END
  
                                        /* Make sure the carrier is valid. */
  SELECT @carrier_objid = objid FROM table_site WHERE site_id = @carrier
  IF @carrier_objid IS NULL AND @carrier <> ''
  BEGIN
     SELECT @ret_val = -16
     GOTO end_proc
  END

                                        /* Get the part number serialization*/
                                        /* If a serialized part and no SN,  */
                                        /*  or if not a serialized part and */
                                        /*  they do have a SN, error.       */
  SELECT @part_objid = part_info2part_num FROM table_mod_level
    WHERE objid = @mod_objid
  SELECT @sn_track = sn_track FROM table_part_num WHERE objid = @part_objid
  IF @sn_track = 0
  BEGIN
     IF @sn <> ''
     BEGIN
        SELECT @ret_val = -17
        GOTO end_proc
     END
  END
  ELSE
  BEGIN
     IF @sn = ''
     BEGIN
        SELECT @ret_val = -18
        GOTO end_proc
     END
  END
  
                                        /* Assume a blank cost string.     */
                                        /* If they are using FIFO costing. */
                                        /* If there's a cost in the PR DTL */
                                        /*  (used for purchase orders), use*/
                                        /*  it. Otherwise, just use regular*/
                                        /*  FIFO costing.                  */
  SELECT @cost_str = ''
  IF @use_fifo = 1
  BEGIN
     IF @cost > 0
     BEGIN
        SELECT @use_fifo = 2
        SELECT @cost_str = CONVERT(char, @cost)
     END
  END


                                        /* Get base objid for database.    */
                                        /* Get objid for recv_object.      */
  SELECT @base_objid = site_id*(268435456) FROM adp_db_header
  EXEC csp_new_oid 40, @recv_objid OUT
  SELECT @recv_objid = @recv_objid + @base_objid

                                        /* Move the part (transaction).    */
                                        /* If any errors, report them.     */
  EXEC trans_internal @dtl_objid, @recv_objid, @mod_objid, @part_objid,
        @f_bin_objid, @f_loc_objid, @from_good, @t_bin_objid, @t_loc_objid,
        @to_good, @quantity, @sn, 2, @user_objid, @r_time, '', '',
        0, @use_fifo, @cost_str, @trans_objid OUT, @ret_val OUT
  IF @ret_val < 0
  BEGIN
     SELECT @ret_val = @ret_val - 100
     GOTO end_proc
  END

                                        /* Get the necessary objids.       */
  EXEC csp_new_oid 21, @act1_objid OUT
  SELECT @act1_objid = @act1_objid + @base_objid
  EXEC csp_new_oid 21, @act2_objid OUT
  SELECT @act2_objid = @act2_objid + @base_objid
  EXEC csp_new_oid 77, @tb1_objid OUT
  SELECT @tb1_objid = @tb1_objid + @base_objid
  EXEC csp_new_oid 77, @tb2_objid OUT
  SELECT @tb2_objid = @tb2_objid + @base_objid

                                        /* Insert recv_parts record. Update*/
                                        /*  part request, condition. Add   */
                                        /*  the act_entry and tb (if needed*/
  BEGIN TRAN
    INSERT INTO table_recv_parts (objid, recv_notes, route_testing, route_problem,
                 receipt_type, recv_carrier, waybill, ship_damage, proper_package,
                 recv_parts2part_info)
      VALUES (@recv_objid, '', @route_to_test, 0, 0, @carrier, @waybill, 
              @poss_damage, @not_prop_pack, @mod_objid)
  
    UPDATE table_demand_dtl SET receipt_date = @r_time, 
            received_qty = received_qty + @quantity, dmnd_dtl_sts2gbst_elm = @new_stat_objid
      WHERE objid = @dtl_objid

    UPDATE table_condition SET title = 'Received', condition = 1048576
      WHERE objid = @cond_objid

      SELECT @t_str = CONVERT(CHAR, @quantity)
      SELECT @add_str = 'Received ' + @t_str + ' units at location: ' + @to_loc +
                        ', Bin: ' + @to_bin
      INSERT INTO table_act_entry (objid, act_code, entry_time, addnl_info, 
        proxy, removed, act_entry2demand_dtl, act_entry2user, entry_name2gbst_elm)
        VALUES (@act1_objid, 12200, @r_time, @add_str, '', 0, @dtl_objid,
                @user_objid, @gbst_objid)
      INSERT INTO table_act_entry (objid, act_code, entry_time, addnl_info, 
        proxy, removed, act_entry2part_trans, act_entry2user, entry_name2gbst_elm)
        VALUES (@act2_objid, 12200, @r_time, @add_str, '', 0, @trans_objid,
                @user_objid, @gbst_objid)

      IF @gen_tb = 1
      BEGIN
         INSERT INTO table_time_bomb (objid, title, escalate_time, end_time, 
           focus_lowid, focus_type, suppl_info, time_period, flags, left_repeat,
           report_title, property_set, users, cmit_creator2employee) VALUES
           (@tb1_objid, '', @past_time, @r_time, @dtl_objid, 49, '', @act1_objid,
           2228226, 0, '', '', '', @emp_objid)
         INSERT INTO table_time_bomb (objid, title, escalate_time, end_time, 
           focus_lowid, focus_type, suppl_info, time_period, flags, left_repeat,
           report_title, property_set, users, cmit_creator2employee) VALUES
           (@tb2_objid, '', @past_time, @r_time, @trans_objid, 244, '', @act2_objid,
           2228226, 0, '', '', '', @emp_objid)
      END
  COMMIT TRAN

                                        /* If they asked for auto-close,   */
                                        /*  try to do it.                  */
                                        /* If they didn't receive them all */
                                        /*  just continue.                 */
  IF @auto_close = 1
  BEGIN
    IF @left_to_rec > @quantity
    BEGIN
       GOTO final_check
    END
    
                                        /* Get default status for new      */
                                        /*  condition. If error, leave.    */
    EXEC get_list_item 'RQST Closed', '', @new_status OUT, @new_stat_objid OUT
    IF @new_status IS NULL OR @new_status = ''
    BEGIN
       SELECT @ret_val = -19
       GOTO end_proc
    END

                                        /* Get activity objid. If not      */
                                        /*  found, error and exit.         */
    SELECT @gbst_objid = objid FROM table_gbst_elm WHERE rank = 11500
    IF @gbst_objid IS NULL
    BEGIN
      SELECT @ret_val = -20
      GOTO end_proc
    END

                                        /* Check to see if we can make the */
                                        /*  transition. If not, error.     */
    EXEC check_cl_trans 'Received', 'Closed', @req_type, @user_name, 
                        @ret_int OUT
    IF @ret_int < 0
    BEGIN
       SELECT @ret_val = -20 + @ret_int
       GOTO end_proc
    END

                                        /* Get the necessary objids.       */
    EXEC csp_new_oid 21, @act1_objid OUT
    SELECT @act1_objid = @act1_objid + @base_objid
    EXEC csp_new_oid 77, @tb1_objid OUT
    SELECT @tb1_objid = @tb1_objid + @base_objid
    SELECT @r_time = DATEADD(ss, 1, @r_time)

                                        /* Update condition, PR detail.    */
                                        /* Add act_entry and tb (if needed)*/
                                        /* If all closed, close the header.*/
    BEGIN TRAN    
      UPDATE table_condition SET title = 'Closed', condition = 4
        WHERE objid = @cond_objid
     
      UPDATE table_demand_dtl SET dmnd_dtl_sts2gbst_elm = @new_stat_objid,
        demand_dtl_wip2wipbin = NULL
        WHERE objid = @dtl_objid
     
      SELECT @add_str = 'Request: ' + @dtl_num + ', Priority: ' + @pri + 
                        ', Site Name: ' + @site_name + ', Condition: Closed, Status: ' +
                        @new_status
      INSERT INTO table_act_entry (objid, act_code, entry_time, addnl_info, 
        proxy, removed, act_entry2demand_dtl, act_entry2user, entry_name2gbst_elm)
        VALUES (@act1_objid, 11500, @r_time, @add_str, '', 0, @dtl_objid,
                @user_objid, @gbst_objid)
       
       IF @gen_tb = 1
       BEGIN
         INSERT INTO table_time_bomb (objid, title, escalate_time, end_time, 
           focus_lowid, focus_type, suppl_info, time_period, flags, left_repeat,
           report_title, property_set, users, cmit_creator2employee) VALUES
           (@tb1_objid, '', @past_time, @r_time, @dtl_objid, 49, '', @act1_objid,
           524290, 0, '', '', '', @emp_objid)         
       END
       
       SELECT @dtl_objid = MIN(objid) FROM table_demand_dtl 
         WHERE demand_dtl2demand_hdr = @hdr_objid AND demand_dtl_wip2wipbin IS NOT NULL
       IF @dtl_objid IS NULL
       BEGIN
         UPDATE table_demand_hdr SET request_status = 'Closed' 
           WHERE objid = @hdr_objid
       END
    COMMIT TRAN
  END

final_check:
                                        /* If we want to receive too many. */
                                        /*  That's OK, just give a warning.*/
  IF @left_to_rec < @quantity
  BEGIN
     SELECT @ret_val = 1
     GOTO end_proc
  END
  
                                        /* All was OK!!!                   */
  SELECT @ret_val = 0
end_proc:
END
go

/***************************************************************************/
/* Receive all Part Requests in a Batch                                    */
/*                                                                         */
/* Copyright (C) 1998. First Choice Software, Inc. All Rights Reserved     */
/***************************************************************************/

CREATE PROCEDURE receive_batch
		 @bat_num VARCHAR(20),
                 @from_loc VARCHAR(20),
                 @from_bin VARCHAR(20),
                 @from_good INT,
		 @to_loc VARCHAR(20),
		 @to_bin VARCHAR(20),
		 @to_good INT,
                 @quantity INT,
                 @serial_num VARCHAR(30),
                 @status VARCHAR(80),
                 @carrier VARCHAR(40),
                 @waybill VARCHAR(40),
                 @poss_damage INT,
                 @not_prop_pack INT,
                 @route_to_test INT,
		 @user_name VARCHAR(30),
		 @receive_date VARCHAR(30),
		 @auto_close INT,
                 @use_fifo INT,
                 @gen_tb INT,
                 @ret_str1 VARCHAR(255) OUTPUT,
		 @ret_val INT OUTPUT AS
BEGIN
  DECLARE @bat_objid INT,               /* Batch objid.                    */
	  @dtl_num VARCHAR(20),         /* Each detail's number.           */
	  @t_ret INT,                   /* Return code for API call for PR */
	  @t_str VARCHAR(10)            /* String for conversion.          */
  
                                        /* Get the batch objid. If not     */
                                        /*  found, error and exit.         */
  SELECT @bat_objid = objid FROM table_batch WHERE batch_num = @bat_num
  IF @bat_objid IS NULL
  BEGIN
    SELECT @ret_val = -1
    GOTO end_proc
  END

                                        /* Assume no errors.               */
  SELECT @ret_val = 0
  
					/* Declare a cursor to find the dtl*/
					/*  records in the batch.          */
  DECLARE bat_cursor CURSOR FOR 
   SELECT detail_number
     FROM table_demand_dtl
     WHERE demand_dtl2batch = @bat_objid
     ORDER BY detail_number

					/* Open the cursor and get rows    */
					/*  until there are no more.       */
					/* For each, change the status.    */
					/* If there's an error, add the    */
					/*  error to the string. Else add 0*/
  OPEN bat_cursor
  FETCH NEXT FROM bat_cursor INTO @dtl_num
  WHILE (@@FETCH_STATUS = 0)
  BEGIN
     EXEC receive @dtl_num, @from_loc, @from_bin, @from_good, @to_loc, @to_bin, 
                  @to_good, @quantity, @serial_num, @status, @carrier, @waybill,
                  @poss_damage, @not_prop_pack, @route_to_test, @user_name, 
                  @receive_date, @auto_close, @use_fifo, @gen_tb, @t_ret OUT
     IF @t_ret <> 0
     BEGIN
        SELECT @ret_val = -2
        SELECT @t_str = CONVERT(VARCHAR(10), @t_ret)
        SELECT @ret_str1 = @ret_str1 + @t_str
     END
     ELSE
     BEGIN
        SELECT @ret_str1 = @ret_str1 + '0'
     END
     
                                        /* Get the next row.               */
     FETCH NEXT FROM bat_cursor INTO @dtl_num
  END

                                        /* Close and deallocate cursor.    */
  CLOSE bat_cursor
  DEALLOCATE bat_cursor
end_proc:
END
go

/***************************************************************************/
/***     Permission granting statements.                                 ***/
/***************************************************************************/

GRANT EXECUTE ON receive TO PUBLIC
go

GRANT EXECUTE ON receive_batch TO PUBLIC
go

/***************************************************************************/
/***     Test routine.                                                   ***/
/***************************************************************************/

IF EXISTS (SELECT * FROM sysobjects WHERE name = 'test')
   DROP PROCEDURE test
go

CREATE PROCEDURE test AS
BEGIN
  DECLARE @ret_val INT,
          @t_str VARCHAR(100),
          @ret_str1 VARCHAR(255)

/*  EXEC receive '1-1', '', '', 1, 'Austin', 'Bin 2', 1, 3, '', '', '', '',
               1, 0, 1, 'sa', '', 1, 1, 1, @ret_val out */
  EXEC receive_batch 'Batch 21', '', '', 1, 'Austin', 'Bin 2', 1, 3, '', '', '', '',
                     1, 0, 1, 'sa', '', 1, 1, 1, @ret_str1 OUT, @ret_val OUT
  SELECT @t_str = CONVERT(CHAR, @ret_val)
  PRINT @t_str 
  IF @ret_val < 0
  BEGIN
     PRINT @ret_str1
  END

END
go

GRANT EXECUTE ON test TO PUBLIC
go

quit

